@@ -1,7 +1,7 @@
 package String::Normal;
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use String::Normal::Type;
 
@@ -50,7 +50,7 @@ sub transform {
 __END__
 =head1 NAME
 
-String::Normal - Transform strings into a normal form.
+String::Normal - Just another normal form string transformer.
 
 =head1 SYNOPSIS
 
@@ -74,6 +74,24 @@ String::Normal - Transform strings into a normal form.
   $normalizer = String::Normal->new( type => 'zip' );
   print $normalizer->transform( '90292' );                     # 90292
 
+=head1 DESCRIPTION
+
+THIS MODULE IS AN ALPHA RELEASE!
+
+Transform strings into a normal form. Performs tokenization, snowball stemming,
+stop word removal and complex name compression.
+
+Consider the following values:
+
+    Bary & Sons' Bakery
+    Bary's & Sons Bakeries
+    Bary's and Sons' Bakeries
+
+These are business names as potentialy found in business listings. 
+When each of these values is passed to C<transform()> the return value
+will be "bakeri bari son." This is accomplished by a number of transformation
+rules, found in the respective C<Type> class.
+
 =head1 CLI TOOLS
 
 =over 4
@@ -90,20 +108,7 @@ Quickly transform values without writing a script:
 
 =back
 
-=head1 DESCRIPTION
-
-THIS MODULE IS AN ALPHA RELEASE!
-
-Normalize your strings. Consider:
-
-    Bary & Sons' Bakery
-    Bary's & Sons Bakeries
-    Bary's and Sons' Bakeries
-
-These are business names as potentialy found in business listings. 
-When each of these values is passed to C<transform()> the return value
-will be "bakeri bari son." This is accomplished by a number of transformation
-rules, found in the respective C<Type> class:
+=head1 TYPE CLASSES
 
 =over 4
 
@@ -145,6 +150,13 @@ and television show titles.
 
 Each type uses data found in a respective Config class:
 
+=head1 CONFIG CLASSES
+
+=head3 Business
+
+Business values are first compressed, then stemmed via L<Lingua::Stem>
+(with customizations) and finally stop worded.
+
 =over 4
 
 =item * L<String::Normal::Config::BusinessStop>
@@ -167,21 +179,29 @@ Compress words are combined into one word. Consider:
 
 These are all "compressed" into the value C<kmart>.
 
+=back
+
+=head3 Address
+
+Address values are first stemmed with a simple substitution and then finally stop worded.
+
+=over 4
+
 =item * L<String::Normal::Config::AddressStop>
 
 Contains stop words to be removed from addresses.
 
 =item * L<String::Normal::Config::AddressStem>
 
-Transforms into some normal form, but does use L<Lingua::Stem>.
+Transforms into some normal form, but does not use L<Lingua::Stem>.
 
-=item * L<String::Normal::Config::State>
+=back
 
-Valide US and Canadian state codes.
+=head3 Title
 
-=item * L<String::Normal::Config::AreaCodes>
+Title values are stop worded first, then stemmed via L<Lingua::Stem>.
 
-Valid US area codes.
+=over 4
 
 =item * L<String::Normal::Config::TitleStop>
 
@@ -189,7 +209,27 @@ Contains stop words to be removed from titles.
 
 =item * L<String::Normal::Config::TitleStem>
 
-Transforms into some normal form, but does use L<Lingua::Stem>.
+Transforms into some normal form, via L<Lingua::Stem> with no customizations.
+
+=back
+
+=head3 State
+
+=over 4
+
+=item * L<String::Normal::Config::State>
+
+Valide US and Canadian state codes.
+
+=back
+
+=head3 Phone
+
+=over 4
+
+=item * L<String::Normal::Config::AreaCodes>
+
+Valid US area codes.
 
 =back
 
