@@ -51,48 +51,14 @@ __DATA__
 mp4
 avi
 mkv
+srt
+idx
+sub
+pt1
+pt2
+cd1
+cd2
+a
 an
 and
-by
-co
-cpa
-ctr
-da
-dd
-de
-dept
-dmd
-dpm
-du
-dvm
-from
-for
-grp
-in
-inc
-inst
-le
-llc
-of
-pa
-pllc
-svc
 the
-to
-assn$
-assoc$
-pc$
-unltd$
-ltd,3
-acctnt$,3 
-agci$,3
-coop,3
-corp$,3
-dc
-^el
-entrprs,3
-etc$,3
-hq$,3
-ind$,3
-intl$,3
-^mr
