@@ -51,7 +51,7 @@ sub transform {
 sub new {
     my $self = shift;
     $STEM = Lingua::Stem->new;
-    $STEM->add_exceptions( String::Normal::Config::BusinessStem::_data( @_ ) );  #TODO: override default files
+    $STEM->add_exceptions( String::Normal::Config::BusinessStem::_data( @_ ) );
     $biz_stop     = String::Normal::Config::BusinessStop::_data( @_ );
     $biz_compress = String::Normal::Config::BusinessCompress::_data( @_ );
     return bless {@_}, $self;
@@ -146,17 +146,15 @@ Creates a Business type. Accepts the following named parameters:
 
 =item * C<business_stem>
 
+Path to text file to override default business name stemming.
+
 =item * C<business_stop>
 
+Path to text file to override default business name stop words.
+
 =item * C<business_compress>
 
-=item * C<address_stem>
-
-=item * C<address_stop>
-
-=item * C<area_codes>
-
-=item * C<states>
+Path to text file to override default business name compressions.
 
 =back
 
