@@ -19,18 +19,23 @@ sub transform {
     # tokenize and stem
     my @tokens = ();
     for my $token (split ' ', $value) {
-        $token = defined( $title_stem->{$token} ) ? $title_stem->{$token} : $token;
+        #$token = defined( $title_stem->{$token} ) ? $title_stem->{$token} : $token;
         push @tokens, $token;
     }
 
-    # remove all middle stop words
+    # Remove all middle stop words that are safe to remove, based on the number of
+    # tokens, of course.
     my @filtered = map {
         my $count = $title_stop->{middle}{$_} || '';
         (length $count and @tokens >= $count) ? () : $_;
     } @tokens;
 
-    # revert if we filtered words down to less than 2 tokens
-    @filtered = @tokens if @filtered < 2;
+    # stem, but override if Stemmer "blanks out" token
+    my @copy = @filtered;
+    $STEM->stem_in_place( @copy );
+    for my $i (0 .. $#copy) {
+        $filtered[$i] = $copy[$i] unless $filtered[$i] =~ /\d/;
+    }
 
     return join ' ', @filtered;
 }
@@ -39,6 +44,8 @@ sub new {
     my $self = shift;
     $title_stem = String::Normal::Config::TitleStem::_data( @_ );
     $title_stop = String::Normal::Config::TitleStop::_data( @_ );
+    $STEM = Lingua::Stem->new;
+    $STEM->add_exceptions( $title_stem );
     return bless {@_}, $self;
 }
 
@@ -71,8 +78,12 @@ Creates a Title type. Accepts the following named parameters:
 
 =item * C<title_stem>
 
+Path to text file to override default title name stemming.
+
 =item * C<title_stop>
 
+Path to text file to override default title name stop words.
+
 =back
 
 =over 4
